@@ -22,7 +22,7 @@ install_common_dependencies()
         sudo apt-get -y install software-properties-common
         sudo add-apt-repository -y ppa:ubuntu-toolchain-r/test
         sudo apt-get -y update
-        sudo apt-get -y install g++-5 cmake pkg-config libboost1.55-serialization-dev libboost1.55-filesystem-dev libboost1.55-system-dev libboost1.55-program-options-dev libboost1.55-test-dev libeigen3-dev libode-dev
+        sudo apt-get -y install g++-5 cmake pkg-config libboost-serialization1.55-dev libboost-filesystem1.55-dev libboost-system1.55-dev libboost-program-options1.55-dev libboost-test1.55-dev libeigen3-dev libode-dev
         export CXX=g++-5
     fi
     export MAKEFLAGS="-j `nproc`"
@@ -40,7 +40,7 @@ install_python_binding_dependencies()
             sudo apt-get -y install libboost-numpy-dev python${PYTHONV}-numpy
         fi
     else
-        sudo apt-get -y install libboost1.55-python-dev
+        sudo apt-get -y install libboost-python1.55-dev
         wget -O - https://midas3.kitware.com/midas/download/item/318227/castxml-linux.tar.gz | tar zxf - -C $HOME
         export PATH=$HOME/castxml/bin:$PATH
     fi
@@ -82,8 +82,8 @@ install_ompl()
     else
         OMPL="omplapp"
     fi
-    wget -O - https://bitbucket.org/ompl/ompl/downloads/$OMPL-1.4.0-Source.tar.gz | tar zxf -
-    cd $OMPL-1.4.0-Source
+    wget -O - https://bitbucket.org/ompl/ompl/downloads/$OMPL-1.4.1-Source.tar.gz | tar zxf -
+    cd $OMPL-1.4.1-Source
     mkdir -p build/Release
     cd build/Release
     cmake ../.. -DPYTHON_EXEC=/usr/bin/python${PYTHONV}
